@@ -4,6 +4,7 @@ from __future__ import print_function
 import sympy as spp
 import numpy as np
 import re
+import pkgutil
 import matplotlib.pyplot as plt
 from pylab import meshgrid,cm,imshow,contour,clabel,colorbar,axis,title,show
 from mpl_toolkits.mplot3d import Axes3D
@@ -20,7 +21,8 @@ import ipywidgets as widgets
 # Establece las variables globales
 # Código HTML para la pestaña de instrucciones 
 instructions_html = None 
-with open('instructions.html', 'r') as file:
+path = pkgutil.get_data(__name__, "instructions.html")
+with open(path, 'r') as file:
     instructions_html = file.read()
 
 __DEBUG__ = False
